BoxEInteraction
===============

.. currentmodule:: pykeen.nn.modules

.. autoclass:: BoxEInteraction
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~BoxEInteraction.entity_shape
      ~BoxEInteraction.relation_shape

   .. rubric:: Methods Summary

   .. autosummary::

      ~BoxEInteraction.boxe_kg_arity_position_score
      ~BoxEInteraction.compute_box
      ~BoxEInteraction.forward
      ~BoxEInteraction.point_to_box_distance
      ~BoxEInteraction.product_normalize

   .. rubric:: Attributes Documentation

   .. autoattribute:: entity_shape
   .. autoattribute:: relation_shape

   .. rubric:: Methods Documentation

   .. automethod:: boxe_kg_arity_position_score
   .. automethod:: compute_box
   .. automethod:: forward
   .. automethod:: point_to_box_distance
   .. automethod:: product_normalize
